@@ -28,10 +28,14 @@
 #'     a character string e.g. 'tcp://127.0.0.1:5555' (see \link{transports}).
 #' @param auth [default NULL] an R object (possessed by both parties) which
 #'     serves as a pre-shared key on which to authenticate the communication.
-#'     Note: the object is never sent, only a random subset of its SHA-512 hash.
+#'     Note: the object is never sent, only a random subset of its md5 hash
+#'     after serialization.
 #'
 #' @return Invisible NULL.
 #'
+#' @note The authentication protocol is an experimental proof of concept which
+#'     is not secure, and should not be used for critical applications.
+#'
 #' @section Usage:
 #'
 #'     Type outgoing messages and hit return to send.
@@ -45,15 +49,12 @@
 #'     party trying to connect will receive an 'authentication error' and be
 #'     disconnected immediately.
 #'
-#'     NOTE: This is currently a proof of concept with an experimental
-#'     authentication protocol and should not be used for critical applications.
-#'
 #' @export
 #'
 messenger <- function(url, auth = NULL) {
 
-  lock <- sha512(auth, convert = FALSE)
-  comb <- order(as.integer(random(32L, convert = FALSE)))
+  lock <- md5_object(auth)
+  comb <- order(as.integer(random(20L, convert = FALSE)))
   key <- c(comb, as.integer(lock)[comb])
 
   sock <- .Call(rnng_messenger, url)
@@ -79,8 +80,8 @@ messenger <- function(url, auth = NULL) {
   } else {
     cat(sprintf("| peer online: %s\n", format.POSIXct(Sys.time())), file = stderr())
     r <- recv(sock, mode = 5L, block = TRUE)
-    for (i in seq_len(32L))
-      lock[r[i]] == r[i + 32L] || {
+    for (i in seq_len(20L))
+      lock[r[i]] == r[i + 20L] || {
         cat("| authentication failed\n", file = stderr())
         return(invisible())
       }
@@ -103,3 +104,10 @@ messenger <- function(url, auth = NULL) {
 }
 
 # nocov end
+
+md5_object <- function(x) {
+  file <- tempfile()
+  on.exit(unlink(file))
+  saveRDS(x, file)
+  charToRaw(md5sum(file))
+}
