@@ -199,7 +199,7 @@ int nano_matcharg(const SEXP);
 int nano_matchargs(const SEXP);
 void nano_serialize(nano_buf *, const SEXP);
 void nano_serialize_next(nano_buf *, const SEXP);
-void nano_serialize_xdr(nano_buf *, const SEXP, const int);
+void nano_serialize_xdr(nano_buf *, const SEXP);
 SEXP nano_unserialize(unsigned char *, const size_t);
 SEXP rawToChar(const unsigned char *, const size_t);
 void dialer_finalizer(SEXP);
@@ -244,7 +244,7 @@ SEXP rnng_ncurl_aio(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 SEXP rnng_ncurl_session(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 SEXP rnng_ncurl_session_close(SEXP);
 SEXP rnng_ncurl_transact(SEXP);
-SEXP rnng_next_config(SEXP, SEXP);
+SEXP rnng_next_config(SEXP, SEXP, SEXP, SEXP);
 SEXP rnng_pipe_notify(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 SEXP rnng_protocol_open(SEXP, SEXP);
 SEXP rnng_random(SEXP, SEXP);
@@ -257,10 +257,6 @@ SEXP rnng_request_signal(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 SEXP rnng_send(SEXP, SEXP, SEXP, SEXP);
 SEXP rnng_send_aio(SEXP, SEXP, SEXP, SEXP, SEXP);
 SEXP rnng_set_opt(SEXP, SEXP, SEXP);
-SEXP rnng_sha224(SEXP, SEXP, SEXP);
-SEXP rnng_sha256(SEXP, SEXP, SEXP);
-SEXP rnng_sha384(SEXP, SEXP, SEXP);
-SEXP rnng_sha512(SEXP, SEXP, SEXP);
 SEXP rnng_signal_thread_create(SEXP, SEXP);
 SEXP rnng_sleep(SEXP);
 SEXP rnng_socket_lock(SEXP, SEXP);
@@ -287,6 +283,7 @@ extern SEXP nano_CvSymbol;
 extern SEXP nano_DataSymbol;
 extern SEXP nano_DialerSymbol;
 extern SEXP nano_DotcallSymbol;
+extern SEXP nano_FdSymbol;
 extern SEXP nano_HeadersSymbol;
 extern SEXP nano_IdSymbol;
 extern SEXP nano_ListenerSymbol;
@@ -306,6 +303,7 @@ extern SEXP nano_aioFormals;
 extern SEXP nano_aioFuncs;
 extern SEXP nano_aioNFuncs;
 extern SEXP nano_error;
+extern SEXP nano_klassString;
 extern SEXP nano_refHook;
 extern SEXP nano_success;
 extern SEXP nano_unresolved;
