@@ -384,6 +384,8 @@ nanotesterr(transact(sess), "ncurlSession")
 nanotestw(is_error_value(ncurl_session("https://i")))
 nanotesterr(ncurl_aio("https://", tls = "wrong"), "valid TLS")
 nanotesterr(ncurl("https://www.cam.ac.uk/", tls = "wrong"), "valid TLS")
+nanotestxp(etls <- tls_config())
+nanotesterr(stream(dial = "wss://127.0.0.1:5555", textframes = TRUE, tls = etls))
 nanotesterr(stream(dial = "wss://127.0.0.1:5555"))
 nanotesterr(stream(dial = "errorValue3"), "argument")
 nanotesterr(stream(dial = "inproc://notsup"), "Not supported")
@@ -553,7 +555,3 @@ nanotestw(dial(s, url = "tls+tcp://.", tls = tls, error = FALSE) > 0)
 nanotestw(listen(s, url = "tls+tcp://.", tls = tls, error = FALSE) > 0)
 nanotestz(close(s1))
 nanotestz(close(s))
-nanotestxp(tls <- tls_config())
-nanotesterr(stream(dial = "wss://127.0.0.1:5555", textframes = TRUE, tls = tls))
-nanotestxp(s <- socket(listen = "wss://127.0.0.1:5557", tls = tls))
-nanotestz(close(s))
